==> accounts_management-0.1.6.gem: app/controllers/accounts_management/documents/invoice_entries_controller.rb <==
require_dependency "accounts_management/accounts_management_controller"

module AccountsManagement
  class Documents::InvoiceEntriesController < AccountsManagementController
    # GET /documents/invoice_entries
    # GET /documents/invoice_entries.json
    def index
      @documents_invoice_entries = Documents::InvoiceEntry.all

      respond_to do |format|
        format.html # index.html.erb
        format.json { render :json => @documents_invoice_entries }
      end
    end

    # GET /documents/invoice_entries/1
    # GET /documents/invoice_entries/1.json
    def show
      @documents_invoice_entry = Documents::InvoiceEntry.find(params[:id])

      respond_to do |format|
        format.html # show.html.erb
        format.json { render :json => @documents_invoice_entry }
      end
    end

    # GET /documents/invoice_entries/new
    # GET /documents/invoice_entries/new.json
    def new
      @documents_invoice_entry = Documents::InvoiceEntry.new

      respond_to do |format|
        format.html # new.html.erb
        format.json { render :json => @documents_invoice_entry }
      end
    end

    # GET /documents/invoice_entries/1/edit
    def edit
      @documents_invoice_entry = Documents::InvoiceEntry.find(params[:id])
    end

    # POST /documents/invoice_entries
    # POST /documents/invoice_entries.json
    def create
      @documents_invoice_entry = Documents::InvoiceEntry.new(params[:documents_invoice_entry])

      respond_to do |format|
        if @documents_invoice_entry.save
          format.html { redirect_to @documents_invoice_entry, :notice => 'Invoice entry was successfully created.' }
          format.json { render :json => @documents_invoice_entry, :status => :created, :location => @documents_invoice_entry }
        else
          format.html { render :action => "new" }
          format.json { render :json => @documents_invoice_entry.errors, :status => :unprocessable_entity }
        end
      end
    end

    # PUT /documents/invoice_entries/1
    # PUT /documents/invoice_entries/1.json
    def update
      @documents_invoice_entry = Documents::InvoiceEntry.find(params[:id])

      respond_to do |format|
        if @documents_invoice_entry.update_attributes(params[:documents_invoice_entry])
          format.html { redirect_to @documents_invoice_entry, :notice => 'Invoice entry was successfully updated.' }
          format.json { head :no_content }
        else
          format.html { render :action => "edit" }
          format.json { render :json => @documents_invoice_entry.errors, :status => :unprocessable_entity }
        end
      end
    end

    # DELETE /documents/invoice_entries/1
    # DELETE /documents/invoice_entries/1.json
    def destroy
      @documents_invoice_entry = Documents::InvoiceEntry.find(params[:id])
      @documents_invoice_entry.destroy

      respond_to do |format|
        format.html { redirect_to documents_invoice_entries_url }
        format.json { head :no_content }
      end
    end
  end
end

==> accounts_management-0.1.7.gem: app/controllers/accounts_management/documents/invoice_entries_controller.rb <==
require_dependency "accounts_management/accounts_management_controller"

module AccountsManagement
  class Documents::InvoiceEntriesController < AccountsManagementController
    # GET /documents/invoice_entries
    # GET /documents/invoice_entries.json
    def index
      @documents_invoice_entries = Documents::InvoiceEntry.all

      respond_to do |format|
        format.html # index.html.erb
        format.json { render json: @documents_invoice_entries }
      end
    end

    # GET /documents/invoice_entries/1
    # GET /documents/invoice_entries/1.json
    def show
      @documents_invoice_entry = Documents::InvoiceEntry.find(params[:id])

      respond_to do |format|
        format.html # show.html.erb
        format.json { render json: @documents_invoice_entry }
      end
    end

    # GET /documents/invoice_entries/new
    # GET /documents/invoice_entries/new.json
    def new
      @documents_invoice_entry = Documents::InvoiceEntry.new

      respond_to do |format|
        format.html # new.html.erb
        format.json { render json: @documents_invoice_entry }
      end
    end

    # GET /documents/invoice_entries/1/edit
    def edit
      @documents_invoice_entry = Documents::InvoiceEntry.find(params[:id])
    end

    # POST /documents/invoice_entries
    # POST /documents/invoice_entries.json
    def create
      @documents_invoice_entry = Documents::InvoiceEntry.new(params[:documents_invoice_entry])

      respond_to do |format|
        if @documents_invoice_entry.save
          format.html { redirect_to @documents_invoice_entry, notice: 'Invoice entry was successfully created.' }
          format.json { render json: @documents_invoice_entry, status: :created, location: @documents_invoice_entry }
        else
          format.html { render action: "new" }
          format.json { render json: @documents_invoice_entry.errors, status: :unprocessable_entity }
        end
      end
    end

    # PUT /documents/invoice_entries/1
    # PUT /documents/invoice_entries/1.json
    def update
      @documents_invoice_entry = Documents::InvoiceEntry.find(params[:id])

      respond_to do |format|
        if @documents_invoice_entry.update_attributes(params[:documents_invoice_entry])
          format.html { redirect_to @documents_invoice_entry, notice: 'Invoice entry was successfully updated.' }
          format.json { head :no_content }
        else
          format.html { render action: "edit" }
          format.json { render json: @documents_invoice_entry.errors, status: :unprocessable_entity }
        end
      end
    end

    # DELETE /documents/invoice_entries/1
    # DELETE /documents/invoice_entries/1.json
    def destroy
      @documents_invoice_entry = Documents::InvoiceEntry.find(params[:id])
      @documents_invoice_entry.destroy

      respond_to do |format|
        format.html { redirect_to documents_invoice_entries_url }
        format.json { head :no_content }
      end
    end
  end
end
